@@ -25,7 +25,8 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.util.Vector;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 
 import com.verisign.epp.codec.gen.EPPCodec;
@@ -42,13 +43,12 @@ import com.verisign.epp.codec.gen.EPPPollCmd;
 import com.verisign.epp.codec.gen.EPPResponse;
 import com.verisign.epp.codec.gen.EPPService;
 import com.verisign.epp.exception.EPPException;
+import com.verisign.epp.pool.parser.EPPSchemaCachingParserPool;
 import com.verisign.epp.transport.EPPClientCon;
 import com.verisign.epp.transport.EPPConException;
 import com.verisign.epp.transport.EPPConFactorySingle;
 import com.verisign.epp.transport.client.EPPSSLContext;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EPPEnv;
-import com.verisign.epp.util.EPPSchemaCachingParser;
 import com.verisign.epp.util.EPPSendReceiveLogger;
 import com.verisign.epp.util.EPPXMLStream;
 
@@ -82,10 +82,9 @@ public class EPPSession {
 	public final static String OP_ACK = EPPPollCmd.OP_ACK;
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static final Logger cat = Logger.getLogger(EPPSession.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPSession.class);
 
 	/**
 	 * Synchronous mode constant in processing commands/responses, where for each
@@ -161,30 +160,22 @@ public class EPPSession {
 	 */
 	protected String msgID = null;
 
-	/** Status transaction identifier */
-	private String statusTransId = null;
-
-	/** Status command type */
-	private String statusCommandType = null;
-
 	/**
 	 * What mode should the EPPSession process command/responses. The mode will
 	 * default to {@code MODE_SYNC} which will send a command an immediately wait
 	 * for the response.
 	 */
-	private int mode = MODE_SYNC;
+	protected int mode = MODE_SYNC;
 
 	/**
 	 * Login adapter used by the {@link #login()}.
 	 */
-	private EPPLoginAdapter loginAdapter;
+	protected EPPLoginAdapter loginAdapter;
 
 	/**
-	 * Log the packet logging and receiver.
-	 * 
-	 * @todo Replace by setting the concrete logger based on configuration.
+	 * Log the packet logging and receiver. 
 	 */
-	private static EPPSendReceiveLogger sendReceiveLogger;
+	protected static EPPSendReceiveLogger sendReceiveLogger;
 
 	static {
 		sendReceiveLogger = EPPEnv.getSendReceiveLogger();
@@ -202,8 +193,8 @@ public class EPPSession {
 	}
 
 	/**
-	 * Construct and initialize a new instance of {@code EPPSession} with a specific host
-	 * and port.
+	 * Construct and initialize a new instance of {@code EPPSession} with a
+	 * specific host and port.
 	 *
 	 * @param aHostName
 	 *           Host name or IP address of host to connect to
@@ -218,8 +209,8 @@ public class EPPSession {
 	}
 
 	/**
-	 * Construct and initialize a new instance of {@code EPPSession} with a specific
-	 * server host, server port, client host name, and client port.
+	 * Construct and initialize a new instance of {@code EPPSession} with a
+	 * specific server host, server port, client host name, and client port.
 	 *
 	 * @param aHostName
 	 *           Host name or IP address of host to connect to
@@ -236,8 +227,8 @@ public class EPPSession {
 	}
 
 	/**
-	 * Construct and initialize a new instance of {@code EPPSession} with a specific host
-	 * and port.
+	 * Construct and initialize a new instance of {@code EPPSession} with a
+	 * specific host and port.
 	 *
 	 * @param aHostName
 	 *           Host name or IP address of host to connect to
@@ -254,8 +245,8 @@ public class EPPSession {
 	}
 
 	/**
-	 * Construct and initialize a new instance of {@code EPPSession} with a specific
-	 * server host, server port, client host name, and client port.
+	 * Construct and initialize a new instance of {@code EPPSession} with a
+	 * specific server host, server port, client host name, and client port.
 	 *
 	 * @param aHostName
 	 *           Host name or IP address of host to connect to
@@ -314,7 +305,6 @@ public class EPPSession {
 		cat.debug("init(): exit");
 	}
 
-
 	/**
 	 * Initializes an {@code EPPSession} to connect to a specific host and port,
 	 * which will do the following:<br>
@@ -468,7 +458,7 @@ public class EPPSession {
 		}
 
 		// Initialize the XML stream
-		this.xmlStream = new EPPXMLStream(EPPSchemaCachingParser.POOL);
+		this.xmlStream = new EPPXMLStream(EPPSchemaCachingParserPool.getInstance().getPool());
 	}
 
 	/**
@@ -489,24 +479,38 @@ public class EPPSession {
 	}
 
 	/**
-	 * This methods does a session login. The following steps are followed:<br>
-	 * <br>
-	 *
-	 * <ul>
-	 * <li>receives a greeting and processes it.</li>
-	 * <li>sends login</li>
-	 * <li>processed login response</li>
-	 * </ul>
-	 *
-	 *
-	 * @exception EPPCommandException
-	 *               Error with login
+	 * Gets the {@link EPPLoginAdapter} set in the {@code EPPSession}.
+	 * 
+	 * @return Set {@link EPPLoginAdapter} if defined; {@code null} otherwise.
 	 */
-	protected void login() throws EPPCommandException {
-		cat.debug("login(): enter");
+	public EPPLoginAdapter getLoginAdapter() {
+		return this.loginAdapter;
+	}
+
+	/**
+	 * Sets the {@link EPPLoginAdapter}. This must be set prior to calling
+	 * {@link #initSession()}.
+	 * 
+	 * @param aLoginAdapter
+	 *           {@link EPPLoginAdapter} to use. Set to {@code null} to not use a
+	 *           login adapter.
+	 */
+	public void setLoginAdapter(EPPLoginAdapter aLoginAdapter) {
+		this.loginAdapter = aLoginAdapter;
+	}
+
+	/**
+	 * This methods processes the greeting received whenever a session is
+	 * established.
+	 *
+	 * @throws EPPCommandException
+	 *               Error with greeting
+   * @return the greeting
+	 */
+	public EPPGreeting processGreeting() throws EPPCommandException {
+		cat.debug("processGreeting(): enter");
 		Document myDoc = null;
 		EPPGreeting myGreeting = null;
-		EPPLoginCmd myCommand = null;
 
 		/**
 		 * Read the incoming Greeting.
@@ -521,15 +525,62 @@ public class EPPSession {
 			sendReceiveLogger.logReceive(this.responsePacket, myGreeting);
 		}
 		catch (EPPDecodeException myException) {
-			cat.error("login(): Exception decoding greeting: " + myException);
-			throw new EPPCommandException("EPPSession.Login() decode [EppDecodeException]: " + myException.getMessage());
+			cat.error("processGreeting(): Exception decoding greeting: " + myException);
+			throw new EPPCommandException(
+			      "EPPSession.processGreeting() decode [EppDecodeException]: " + myException.getMessage());
 		}
 		catch (NullPointerException myException) {
-			cat.error("login(): Exception decoding greeting: " + myException);
+			cat.error("processGreeting(): Exception decoding greeting: " + myException);
 			throw new EPPCommandException(
-			      "EPPSession.Login () decode [Null Pointer Exception] : " + myException.getMessage());
+			      "EPPSession.processGreeting () decode [Null Pointer Exception] : " + myException.getMessage());
 		}
 
+		cat.debug("lprocessGreeting(): exit");
+		return myGreeting;
+	}
+
+	/**
+	 * This methods does a session login. The following steps are followed:<br>
+	 * <br>
+	 *
+	 * <ul>
+	 * <li>receives a greeting and processes it.</li>
+	 * <li>sends login</li>
+	 * <li>processed login response</li>
+	 * </ul>
+	 *
+	 *
+	 * @exception EPPCommandException
+	 *               Error with login
+	 */
+	protected void login() throws EPPCommandException {
+		EPPGreeting myGreeting = processGreeting();
+		login(myGreeting);
+	}
+
+	/**
+	 * This methods does a session login. The following steps are followed:<br>
+	 * <br>
+	 *
+	 * <ul>
+	 * <li>receives a greeting and processes it.</li>
+	 * <li>sends login</li>
+	 * <li>processed login response</li>
+	 * </ul>
+	 * 
+	 * @param myGreeting
+	 *           Greeting that is used in determining the services to include in
+	 *           the login command
+	 *
+	 *
+	 * @exception EPPCommandException
+	 *               Error with login
+	 */
+	protected void login(EPPGreeting myGreeting) throws EPPCommandException {
+		cat.debug("login(EPPGreeting): enter");
+		Document myDoc = null;
+		EPPLoginCmd myCommand = null;
+
 		/**
 		 * Need to Create a Command Object and set Attributes.
 		 */
@@ -564,21 +615,19 @@ public class EPPSession {
 
 		// Greeting and Login services are not compatible?
 		if (cat.isDebugEnabled() && !myCommand.isValidServices(myGreeting)) {
-			cat.debug("Login services does not match the greeting services, greeting = [" + myGreeting + "], login = ["
-			      + myCommand + "]");
+			cat.debug("login(EPPGreeting): Login services does not match the greeting services, greeting = [" + myGreeting
+			      + "], login = [" + myCommand + "]");
 		}
 
 		// Execute the login adapter?
 		if (this.loginAdapter != null) {
-			cat.debug("Adapt login command with " + this.loginAdapter.getClass().getName());
+			cat.debug("login(EPPGreeting): Adapt login command with " + this.loginAdapter.getClass().getName());
 			this.loginAdapter.adaptLogin(myCommand, myGreeting);
 		}
 		else {
 			cat.debug("No login adapter defined");
 		}
 
-		cat.debug("Sending login command: " + myCommand);
-
 		/**
 		 * now we need to send the message (doc --> CommandObject)
 		 */
@@ -586,9 +635,9 @@ public class EPPSession {
 			myDoc = this.codec.encode(myCommand);
 		}
 		catch (EPPEncodeException myException) {
-			cat.error("login(): Exception encoding login command: " + myException);
-			throw new EPPCommandException("EPPSession.login() decode : " + myException.getMessage());
-		}
+			cat.error("login(EPPGreeting): Exception encoding login command: " + myException);
+			throw new EPPCommandException("login(EPPGreeting): encode exception:" + myException.getMessage());
+		}		
 
 		/**
 		 * Write the Login into the Stream.
@@ -608,7 +657,7 @@ public class EPPSession {
 			sendReceiveLogger.logReceive(this.responsePacket, this.response);
 		}
 		catch (EPPDecodeException myException) {
-			cat.error("login(): Exception decoding login response: " + myException);
+			cat.error("login(EPPGreeting): Exception decoding login response: " + myException);
 			throw new EPPCommandException("EPPSession.initialize() decode : " + myException.getMessage());
 		}
 
@@ -616,7 +665,7 @@ public class EPPSession {
 		 * Server specified error?
 		 */
 		if (!this.response.isSuccess()) {
-			cat.error("login(): Login failure response: " + this.response);
+			cat.error("login(EPPGreeting): Login failure response: " + this.response);
 			throw new EPPCommandException("EPPSession.login() : Error in response from Server ", this.response);
 		}
 
@@ -628,7 +677,7 @@ public class EPPSession {
 		// Reset the transaction id
 		this.transId = null;
 
-		cat.debug("login(): exit");
+		cat.debug("login(EPPGreeting): exit");
 	}
 
 	/**
@@ -710,7 +759,8 @@ public class EPPSession {
 	 *
 	 * @return the response from the poll command
 	 *
-	 * @exception EPPCommandException Error sending the poll command
+	 * @exception EPPCommandException
+	 *               Error sending the poll command
 	 */
 	public EPPResponse sendPoll() throws EPPCommandException {
 		cat.debug("sendPoll(): enter");
@@ -727,7 +777,8 @@ public class EPPSession {
 	/**
 	 * logout from the session.
 	 *
-	 * @exception EPPCommandException Error sending the logout command
+	 * @exception EPPCommandException
+	 *               Error sending the logout command
 	 */
 	protected void logout() throws EPPCommandException {
 		cat.debug("logout(): enter");
@@ -782,9 +833,9 @@ public class EPPSession {
 			sendReceiveLogger.logReceive(this.responsePacket, this.response);
 
 		}
-		catch (EPPDecodeException myException) {
-			cat.error("logout(): Exception decoding response: " + myException);
-			throw new EPPCommandException("EPPSession.logout() decode : " + myException.getMessage());
+		catch (EPPDecodeException ex) {
+			cat.error("logout(): Exception decoding response: " + ex);
+			throw new EPPCommandException("EPPSession.logout() decode : " + ex.getMessage());
 		}
 
 		/**
@@ -854,13 +905,13 @@ public class EPPSession {
 			this.responsePacket = this.xmlStream.readPacket(this.inputStream);
 			myDoc = this.xmlStream.decodePacket(this.responsePacket);
 		}
-		catch (EPPException myException) {
-			cat.error("recDocument(): Exception reading from stream: " + myException);
-			throw new EPPCommandException("EPPCommand.recDocument : " + myException.getMessage());
+		catch (EPPException ex) {
+			cat.error("recDocument(): Exception reading from stream: " + ex);
+			throw new EPPCommandException("EPPCommand.recDocument : " + ex.getMessage());
 		}
-		catch (IOException myException) {
-			cat.error("recDocument(): Exception reading from stream: " + myException);
-			throw new EPPCommandException("EPPCommand.recDocument : " + myException.getMessage());
+		catch (IOException ex) {
+			cat.error("recDocument(): Exception reading from stream: " + ex);
+			throw new EPPCommandException("EPPCommand.recDocument : " + ex.getMessage(), ex);
 		}
 
 		return myDoc;
@@ -937,7 +988,7 @@ public class EPPSession {
 		}
 		catch (IOException ex) {
 			cat.error("sendPacket(): Exception writing to stream: " + ex);
-			throw new EPPCommandException("EPPSession.sendPacket() : " + ex.getMessage());
+			throw new EPPCommandException("EPPSession.sendPacket() : " + ex.getMessage(), ex);
 		}
 
 	}
@@ -1046,12 +1097,14 @@ public class EPPSession {
 		if (!theResponse.isSuccess()) {
 			throw new EPPCommandException("EPPSession.processDocument() : Error in response from Server", this.response);
 		}
-
+		
+		
 		// Specific response expected and response does not match expected type?
 		if ((aExpectedResponse != null) && !aExpectedResponse.isInstance(theResponse)) {
 			throw new EPPCommandException(
 			      "Unexpected response type of " + theResponse.getClass().getName() + ", expecting " + aExpectedResponse);
 		}
+		
 
 		// Client transaction's match?
 		validateClientTransId(aCommand, theResponse);
@@ -1165,17 +1218,72 @@ public class EPPSession {
 		cat.debug("initSession(): enter");
 		// Validate attributes
 		if (this.clientId == null) {
-			throw new EPPCommandException("EPPSession.initSession Login requires ClientID");
+			throw new EPPCommandException("EPPSession.initSession(): Login requires ClientID");
 		}
 
 		if (this.password == null) {
-			throw new EPPCommandException("EPPSession.initSession Login requires Password");
+			throw new EPPCommandException("EPPSession.initSession(): Login requires Password");
 		}
 
 		login();
 		cat.debug("initSession(): exit");
 	}
 
+	/**
+	 * Initialize an authenticated session with the EPP Server.<br>
+	 * <br>
+	 * The required attributes have been set with the following methods:<br>
+	 * <br>
+	 *
+	 * <ul>
+	 * <li>{@code setClientID} - Sets the client idenfifier/user name</li>
+	 * <li>{@code setPassword} - Sets the password</li>
+	 * </ul>
+	 *
+	 * <br>
+	 * <br>
+	 * The optional attributes have been set with the following:<br>
+	 * <br>
+	 *
+	 * <ul>
+	 * <li>{@code setNewPassword} - Changes the password</li>
+	 * <li>{@code setVersion} - Override the default EPP version. A default
+	 * setting is provided (i.e. 1.0).</li>
+	 * <li>{@code setLang} - Override the default language of "us".</li>
+	 * <li>{@code setServices} - Sets desired set of client EPP services by EPP
+	 * XML Namespace. A default setting is automatically provided based on the
+	 * {@code EPP.MapFactories} configuration setting</li>
+	 * <li>{@code setExtensions} - Sets desired set of client EPP services. This
+	 * can be a subset of the EPP services loaded in the client. A default
+	 * setting is automatically provided based on the
+	 * {@code EPP.ProtocolExtension} and the {@code EPP.CmdRspExtensions}
+	 * configuration settings.</li>
+	 * </ul>
+	 * 
+	 * @param myGreeting
+	 *           Greeting that is used in determining the services to include in
+	 *           the login command
+	 *
+	 *
+	 * @exception EPPCommandException
+	 *               Error initializing the session.
+	 */
+	public void initSession(EPPGreeting myGreeting) throws EPPCommandException {
+		cat.debug("initSession(EPPGreeting): enter");
+
+		// Validate attributes
+		if (this.clientId == null) {
+			throw new EPPCommandException("EPPSession.initSession(EPPGreeting): Login requires ClientID");
+		}
+
+		if (this.password == null) {
+			throw new EPPCommandException("EPPSession.initSession(EPPGreeting): Login requires Password");
+		}
+
+		login(myGreeting);
+		cat.debug("initSession(EPPGreeting): exit");
+	}
+
 	/**
 	 * Gets the EPP version used in {@code initSession}.
 	 *
@@ -1508,53 +1616,6 @@ public class EPPSession {
 		return this.pollOp;
 	}
 
-	/**
-	 * Gets the status client transaction identifier.
-	 *
-	 * @return Status client transaction identifier if defined; {@code null}
-	 *         otherwise.
-	 */
-	public String getStatusTransId() {
-		return this.statusTransId;
-	}
-
-	/**
-	 * Sets the status client transaction identifier.
-	 *
-	 * @param aStatusTrans
-	 *           Status client transaction identifier.
-	 */
-	public void setStatusTransId(String aStatusTrans) {
-		this.statusTransId = aStatusTrans;
-	}
-
-	/**
-	 * Gets the status command type. The command type should be one of the valid
-	 * {@code EPPCommand.TYPE_} constants.
-	 *
-	 * @return Status status command type if defined; {@code null} otherwise.
-	 */
-	public String getStatusCommandType() {
-		return this.statusCommandType;
-	}
-
-	/**
-	 * Sets the status command type.
-	 *
-	 * @param aStatusCommandType
-	 *           Status command type, which should be one of the following:<br>
-	 *           <ul>
-	 *           <li>{@code EPPCommand.TYPE_CREATE}
-	 *           <li>{@code EPPCommand.TYPE_DELETE}
-	 *           <li>{@code EPPCommand.TYPE_RENEW}
-	 *           <li>{@code EPPCommand.TYPE_TRANSFER}
-	 *           <li>{@code EPPCommand.TYPE_UPDATE}
-	 *           </ul>
-	 */
-	public void setStatusCommandType(String aStatusCommandType) {
-		this.statusCommandType = aStatusCommandType;
-	}
-
 	/**
 	 * Gets the poll Message Id.
 	 *
@@ -1625,4 +1686,4 @@ public class EPPSession {
 		}
 	}
 
-}
\ No newline at end of file
+}
