@@ -31,8 +31,6 @@ import com.verisign.epp.codec.gen.EPPGreeting;
 import com.verisign.epp.codec.gen.EPPResponse;
 import com.verisign.epp.codec.gen.EPPResult;
 import com.verisign.epp.transport.client.EPPSSLClientSocket;
-import com.verisign.epp.interfaces.RenegotiationSession;
-
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
@@ -42,13 +40,13 @@ import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
 /**
- * Is a unit test of the EPPSession class. The unit test will initialize a
- * session with an EPP Server and end a session with an EPP Server. The
- * configuration file used by the unit test defaults to epp.config, but can be
+ * Is a unit test of the {@code EPPSession} class. The unit test will initialize
+ * a session with an EPP Server and end a session with an EPP Server. The
+ * configuration file used by the unit test defaults to "epp.config", but can be
  * changed by passing the file path as the first command line argument. The unit
  * test can be run in multiple threads by setting the "threads" system property.
  * For example, the unit test can be run in 2 threads with the configuration
- * file ../../epp.config with the following command:<br>
+ * file "../../epp.config" with the following command:<br>
  * <br>
  * java com.verisign.epp.interfaces.EPPSessionTst -Dthreads=2 ../../epp.config
  * <br>
@@ -57,18 +55,11 @@ import junit.framework.TestSuite;
  * configured (i.e. Domain). Without one EPP Command Mapping, the XML Schema
  * validation will fail when the client parses the greeting message from the EPP
  * Server Stub. <br>
- * <br>
- * The unit test is dependent on the use of <a
- * href=http://www.mcwestcorp.com/Junit.html>JUNIT 3.5</a><br>
- * <br>
- *
- * @author $Author: jim $
- * @version $Revision: 1.5 $
  */
 public class EPPSessionTst extends TestCase {
 	/**
 	 * Handle to the Singleton EPP Application instance (
-	 * <code>EPPApplicationSingle</code>)
+	 * {@code EPPApplicationSingle})
 	 */
 	private static EPPApplicationSingle app = EPPApplicationSingle.getInstance();
 
@@ -82,9 +73,8 @@ public class EPPSessionTst extends TestCase {
 	private EPPSession session = null;
 
 	/**
-	 * Allocates an <code>EPPSessionTst</code> with a logical name. The
-	 * constructor will initialize the base class <code>TestCase</code> with the
-	 * logical name.
+	 * Allocates an {@code EPPSessionTst} with a logical name. The constructor
+	 * will initialize the base class {@code TestCase} with the logical name.
 	 *
 	 * @param name
 	 *           Logical name of the test
@@ -94,9 +84,9 @@ public class EPPSessionTst extends TestCase {
 	}
 
 	/**
-	 * JUNIT test method to implement the <code>EPPSessionTst TestCase</code>.
-	 * Each sub-test will be invoked in order to satisfy testing the
-	 * initialization and ending of an EPP Session with an EPP Server.
+	 * JUNIT test method to implement the {@code EPPSessionTst TestCase}. Each
+	 * sub-test will be invoked in order to satisfy testing the initialization
+	 * and ending of an EPP Session with an EPP Server.
 	 */
 	public void testSession() {
 		initSession();
@@ -115,6 +105,14 @@ public class EPPSessionTst extends TestCase {
 	public void testClientInitiatedRenegotation() {
 		printStart("testClientInitiatedRenegotation");
 
+		String theSSLProtocol = Environment.getProperty("EPP.SSLProtocol");
+		if (theSSLProtocol != null && theSSLProtocol.equals("TLSv1.3")) {
+			System.out.println(
+			      Thread.currentThread().getName() + ": testClientInitiatedRenegotation:: skipping since TLSv1.3");
+			printEnd("testClientInitiatedRenegotation");
+			return;
+		}
+
 		RenegotiationSession theSession = null;
 
 		try {
@@ -157,7 +155,7 @@ public class EPPSessionTst extends TestCase {
 	}
 
 	/**
-	 * Unit test of <code>EPPSession.initSession</code>. The session attribute is
+	 * Unit test of {@code EPPSession.initSession}. The session attribute is
 	 * initialized with the attributes defined in the EPP sample files.
 	 */
 	private void initSession() {
@@ -168,15 +166,15 @@ public class EPPSessionTst extends TestCase {
 		String thePassword = Environment.getProperty("EPP.Test.password", "foo-BAR2");
 
 		// Set attributes for initSession
-		session.setClientID(theClientId);
-		session.setPassword(thePassword);
-		session.setTransId("ABC-12345-XYZ");
-		session.setVersion("1.0");
-		session.setLang("en");
+		this.session.setClientID(theClientId);
+		this.session.setPassword(thePassword);
+		this.session.setTransId("ABC-12345-XYZ");
+		this.session.setVersion("1.0");
+		this.session.setLang("en");
 
 		try {
 			// Initialize the session
-			session.initSession();
+			this.session.initSession();
 		}
 		catch (
 
@@ -188,15 +186,14 @@ public class EPPSessionTst extends TestCase {
 	}
 
 	/**
-	 * Unit test of <code>EPPSession.sendHello</code> command. The session
-	 * attribute is initialized with the attributes defined in the EPP sample
-	 * files.
+	 * Unit test of {@code EPPSession.sendHello} command. The session attribute
+	 * is initialized with the attributes defined in the EPP sample files.
 	 */
 	private void doHello() {
 		printStart("Session Hello");
 
 		try {
-			session.hello();
+			this.session.hello();
 		}
 		catch (EPPCommandException e) {
 			handleException(e);
@@ -206,18 +203,25 @@ public class EPPSessionTst extends TestCase {
 	}
 
 	/**
-	 * Unit test of <code>EPPSession.sendPacket</code> command. This test will
-	 * encode a Hello packet and send it using the
-	 * {@link EPPSession#sendPacket(byte[])} method. The greeting will be read
-	 * using the {@link EPPSession#readResponse()} method.
+	 * Unit test of {@code EPPSession.sendPacket} command. This test will encode
+	 * a Hello packet and send it using the {@link EPPSession#sendPacket(byte[])}
+	 * method. The greeting will be read using the
+	 * {@link EPPSession#readResponse()} method.
 	 */
 	private void doSendPacket() {
 		printStart("doSendPacket");
 
+		if (!this.session.isModeSupported(EPPSession.MODE_ASYNC)) {
+			System.out.println("doSendPacket: Session " + this.session.getClass().getName()
+			      + " does not support MODE_ASYNC, skipping test");
+			printEnd("doSendPacket (skipped)");
+			return;
+		}
+		
 		try {
 
 			// Send packet over session
-			session.sendPacket(
+			this.session.sendPacket(
 			      "<?xml version=\"1.0\" encoding=\"UTF-8\"?><epp xmlns=\"urn:ietf:params:xml:ns:epp-1.0\"><hello/></epp>"
 			            .getBytes());
 
@@ -225,9 +229,9 @@ public class EPPSessionTst extends TestCase {
 			Document theDoc = null;
 
 			// Read response from server and parse the XML to DOM Document
-			theDoc = session.recDocument();
+			theDoc = this.session.recDocument();
 
-			// Decode DOM Document to <code>EPPGreeting</code> instance
+			// Decode DOM Document to {@code EPPGreeting} instance
 			try {
 				EPPGreeting greeting = (EPPGreeting) EPPCodec.getInstance().decode(theDoc);
 				System.out.println("doSendPacket: Greeting = [" + greeting + "]\n\n");
@@ -245,12 +249,18 @@ public class EPPSessionTst extends TestCase {
 
 	/**
 	 * Unit test of attempting to send the server an invalid request, which is
-	 * sending the server an <code>EPPResponse</code> or an
-	 * <code>EPPGreeting</code>>.
+	 * sending the server an {@code EPPResponse} or an {@code EPPGreeting}>.
 	 */
 	private void doSendInvalidRequest() {
 		printStart("doSendInvalidRequest");
 
+		if (!this.session.isModeSupported(EPPSession.MODE_ASYNC)) {
+			System.out.println("doSendInvalidRequest: Session " + this.session.getClass().getName()
+			      + " does not support MODE_ASYNC, skipping test");
+			printEnd("doSendInvalidRequest (skipped)");
+			return;
+		}
+		
 		try {
 			// Send an EPP Response
 			this.session.sendMessage(new EPPResponse());
@@ -259,9 +269,9 @@ public class EPPSessionTst extends TestCase {
 			Document theDoc = null;
 
 			// Read response from server and parse the XML to DOM Document
-			theDoc = session.recDocument();
+			theDoc = this.session.recDocument();
 
-			// Decode DOM Document to <code>EPPResponse</code> instance
+			// Decode DOM Document to {@code EPPResponse} instance
 			try {
 				EPPResponse response = (EPPResponse) EPPCodec.getInstance().decode(theDoc);
 				System.out.println("doSendInvalidRequest: Response = [" + response + "]\n\n");
@@ -285,9 +295,9 @@ public class EPPSessionTst extends TestCase {
 			theDoc = null;
 
 			// Read response from server and parse the XML to DOM Document
-			theDoc = session.recDocument();
+			theDoc = this.session.recDocument();
 
-			// Decode DOM Document to <code>EPPResponse</code> instance
+			// Decode DOM Document to {@code EPPResponse} instance
 			try {
 				EPPResponse response = (EPPResponse) EPPCodec.getInstance().decode(theDoc);
 				System.out.println("doSendInvalidRequest: Response = [" + response + "]\n\n");
@@ -312,7 +322,7 @@ public class EPPSessionTst extends TestCase {
 	}
 
 	/**
-	 * Unit test of <code>EPPSession.sendPoll</code> command.
+	 * Unit test of {@code EPPSession.sendPoll} command.
 	 */
 	private void doPoll() {
 		printStart("doPoll");
@@ -321,9 +331,9 @@ public class EPPSessionTst extends TestCase {
 		Long numMsgs = null;
 
 		try {
-			session.setTransId("ABC-12345-XYZ");
-			session.setPollOp(EPPSession.OP_REQ);
-			response = session.sendPoll();
+			this.session.setTransId("ABC-12345-XYZ");
+			this.session.setPollOp(EPPSession.OP_REQ);
+			response = this.session.sendPoll();
 
 			// -- Output all of the response attributes
 			System.out.println("doPoll: Response = [" + response + "]\n\n");
@@ -339,10 +349,10 @@ public class EPPSessionTst extends TestCase {
 		}
 
 		try {
-			session.setTransId("ABC-12345-XYZ");
-			session.setPollOp(EPPSession.OP_ACK);
-			session.setMsgID("1234");
-			response = session.sendPoll();
+			this.session.setTransId("ABC-12345-XYZ");
+			this.session.setPollOp(EPPSession.OP_ACK);
+			this.session.setMsgID("1234");
+			response = this.session.sendPoll();
 
 			// -- Output all of the response attributes
 			System.out.println("doPoll: Response = [" + response + "]\n\n");
@@ -357,7 +367,7 @@ public class EPPSessionTst extends TestCase {
 
 	/**
 	 * Read all of the poll queue messages from the poll queue via the
-	 * <code>EPPSession.sendPoll</code> command.
+	 * {@code EPPSession.sendPoll} command.
 	 */
 	private void doPollConsume() {
 		printStart("doPollConsume");
@@ -365,24 +375,24 @@ public class EPPSessionTst extends TestCase {
 		EPPResponse response = null;
 
 		try {
-			session.setTransId("ABC-" + System.currentTimeMillis());
-			session.setPollOp(EPPSession.OP_REQ);
-			response = session.sendPoll();
+			this.session.setTransId("ABC-" + System.currentTimeMillis());
+			this.session.setPollOp(EPPSession.OP_REQ);
+			response = this.session.sendPoll();
 
 			while (response.getResult().getCode() == EPPResult.SUCCESS_POLL_MSG) {
 
 				System.out.println("doPollConsume: Message = [" + response + "]\n\n");
 
 				// Acknowledge current message
-				session.setTransId("ABC-" + System.currentTimeMillis());
-				session.setPollOp(EPPSession.OP_ACK);
-				session.setMsgID(response.getMsgQueue().getId());
-				response = session.sendPoll();
+				this.session.setTransId("ABC-" + System.currentTimeMillis());
+				this.session.setPollOp(EPPSession.OP_ACK);
+				this.session.setMsgID(response.getMsgQueue().getId());
+				response = this.session.sendPoll();
 
 				// Send next poll request
-				session.setTransId("ABC-" + System.currentTimeMillis());
-				session.setPollOp(EPPSession.OP_REQ);
-				response = session.sendPoll();
+				this.session.setTransId("ABC-" + System.currentTimeMillis());
+				this.session.setPollOp(EPPSession.OP_REQ);
+				response = this.session.sendPoll();
 			}
 
 		}
@@ -400,24 +410,24 @@ public class EPPSessionTst extends TestCase {
 	private void doAsyncPoll() {
 		printStart("doAsyncPoll");
 
-		if (!session.isModeSupported(EPPSession.MODE_ASYNC)) {
-			System.out.println(
-			      "doAsyncPoll: Session " + session.getClass().getName() + " does not support MODE_ASYNC, skipping test");
+		if (!this.session.isModeSupported(EPPSession.MODE_ASYNC)) {
+			System.out.println("doAsyncPoll: Session " + this.session.getClass().getName()
+			      + " does not support MODE_ASYNC, skipping test");
 			printEnd("doAsyncPoll (skipped)");
 			return;
 		}
-		int previousSessionMode = session.setMode(EPPSession.MODE_ASYNC);
+		int previousSessionMode = this.session.setMode(EPPSession.MODE_ASYNC);
 
 		try {
 			String theClientTransId = "ASYNC-CMD-" + System.currentTimeMillis();
-			session.setTransId(theClientTransId);
-			session.setPollOp(EPPSession.OP_REQ);
-			EPPResponse thePollResp = session.sendPoll();
+			this.session.setTransId(theClientTransId);
+			this.session.setPollOp(EPPSession.OP_REQ);
+			EPPResponse thePollResp = this.session.sendPoll();
 
 			Assert.assertNull("doAsyncPoll: sendPoll() response " + thePollResp + " != null", thePollResp);
 
 			// Asynchronously read the poll response
-			EPPResponse theResponse = session.readResponse();
+			EPPResponse theResponse = this.session.readResponse();
 
 			Assert.assertEquals("doAsyncPoll: clientTransId's don't Match (command and response)", theClientTransId,
 			      theResponse.getTransId().getClientTransId());
@@ -426,24 +436,24 @@ public class EPPSessionTst extends TestCase {
 			handleException(e);
 		}
 		finally {
-			session.setMode(previousSessionMode);
+			this.session.setMode(previousSessionMode);
 		}
 
 		printEnd("doAsyncPoll");
 	}
 
 	/**
-	 * Unit test of <code>EPPSession.endSession</code>. The session with the EPP
+	 * Unit test of {@code EPPSession.endSession}. The session with the EPP
 	 * Server will be terminated.
 	 */
 	private void endSession() {
 		printStart("endSession");
 
-		session.setTransId("ABC-12345-XYZ");
+		this.session.setTransId("ABC-12345-XYZ");
 
 		// End the session
 		try {
-			session.endSession();
+			this.session.endSession();
 		}
 		catch (EPPCommandException e) {
 			handleException(e);
@@ -453,9 +463,10 @@ public class EPPSessionTst extends TestCase {
 	}
 
 	/**
-	 * JUNIT <code>setUp</code> method, which sets the default client Id to
+	 * JUNIT {@code setUp} method, which sets the default client Id to
 	 * "theRegistrar".
 	 */
+	@Override
 	protected void setUp() {
 		try {
 			String theSessionClassName = System.getProperty("EPP.SessionClass");
@@ -468,14 +479,14 @@ public class EPPSessionTst extends TestCase {
 						Assert.fail(theSessionClassName + " is not a subclass of EPPSession");
 					}
 
-					session = (EPPSession) theSessionClass.getDeclaredConstructor().newInstance();
+					this.session = (EPPSession) theSessionClass.getDeclaredConstructor().newInstance();
 				}
 				catch (Exception ex) {
 					Assert.fail("Exception instantiating EPP.SessionClass value " + theSessionClassName + ": " + ex);
 				}
 			}
 			else {
-				session = new EPPSession();
+				this.session = new EPPSession();
 			}
 		}
 		catch (Exception e) {
@@ -484,17 +495,16 @@ public class EPPSessionTst extends TestCase {
 		}
 	}
 
-	// End EPPSessionTst.setUp();
-
 	/**
-	 * JUNIT <code>tearDown</code>, which currently does nothing.
+	 * JUNIT {@code tearDown}, which currently does nothing.
 	 */
+	@Override
 	protected void tearDown() {
 	}
 
 	/**
-	 * JUNIT <code>suite</code> static method, which returns the tests associated
-	 * with <code>EPPSessionTst</code>.
+	 * JUNIT {@code suite} static method, which returns the tests associated with
+	 * {@code EPPSessionTst}.
 	 *
 	 * @return Tests to execute
 	 */
@@ -502,8 +512,9 @@ public class EPPSessionTst extends TestCase {
 		TestSuite suite = new TestSuite(EPPSessionTst.class);
 
 		String theConfigFileName = System.getProperty("EPP.ConfigFile");
-		if (theConfigFileName != null)
+		if (theConfigFileName != null) {
 			configFileName = theConfigFileName;
+		}
 
 		try {
 			app.initialize(configFileName);
@@ -518,17 +529,16 @@ public class EPPSessionTst extends TestCase {
 
 	/**
 	 * Unit test main, which accepts the following system property options:<br>
-	 * 
+	 *
 	 * <ul>
 	 * <li>iterations Number of unit test iterations to run</li>
-	 * <li>validate Turn XML validation on (<code>true</code>) or off (
-	 * <code>false</code>). If validate is not specified, validation will be off.
-	 * </li>
+	 * <li>validate Turn XML validation on ({@code true}) or off (
+	 * {@code false}). If validate is not specified, validation will be off.</li>
 	 * </ul>
-	 * 
+	 *
 	 *
 	 * @param args
-	 *           DOCUMENT ME!
+	 *           Command line arguments
 	 */
 	public static void main(String[] args) {
 		// Override the default configuration file name?
@@ -566,7 +576,7 @@ public class EPPSessionTst extends TestCase {
 	}
 
 	/**
-	 * Handle an <code>EPPCommandException</code>, which can be either a server
+	 * Handle an {@code EPPCommandException}, which can be either a server
 	 * generated error or a general exception. If the exception was caused by a
 	 * server error, "Server Error : &lt;Response XML&gt;" will be specified. If
 	 * the exception was caused by a general algorithm error, "General Error :
@@ -576,7 +586,7 @@ public class EPPSessionTst extends TestCase {
 	 *           Exception thrown during test
 	 */
 	public void handleException(EPPCommandException aException) {
-		EPPResponse response = session.getResponse();
+		EPPResponse response = this.session.getResponse();
 
 		// Is a server specified error?
 		if ((response != null) && (!response.isSuccess())) {
@@ -589,8 +599,8 @@ public class EPPSessionTst extends TestCase {
 	}
 
 	/**
-	 * Print the start of a test with the <code>Thread</code> name if the current
-	 * thread is a <code>TestThread</code>.
+	 * Print the start of a test with the {@code Thread} name if the current
+	 * thread is a {@code TestThread}.
 	 *
 	 * @param aTest
 	 *           name for the test
@@ -606,8 +616,8 @@ public class EPPSessionTst extends TestCase {
 	}
 
 	/**
-	 * Print the end of a test with the <code>Thread</code> name if the current
-	 * thread is a <code>TestThread</code>.
+	 * Print the end of a test with the {@code Thread} name if the current thread
+	 * is a {@code TestThread}.
 	 *
 	 * @param aTest
 	 *           name for the test
