@@ -19,18 +19,12 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 ***********************************************************/
 package com.verisign.epp.serverstub;
 
-import java.io.File;
-import java.io.IOException;
-// Java imports
-import java.net.URL;
 import java.util.Enumeration;
 import java.util.Vector;
 
-// Log4J Imports
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-// EPP imports
 import com.verisign.epp.codec.gen.EPPCodecException;
 import com.verisign.epp.codec.gen.EPPFactory;
 import com.verisign.epp.framework.EPPAssembler;
@@ -41,20 +35,15 @@ import com.verisign.epp.framework.EPPXMLAssembler;
 import com.verisign.epp.transport.EPPConException;
 import com.verisign.epp.transport.EPPServerCon;
 import com.verisign.epp.transport.EPPSrvFactorySingle;
-
 import com.verisign.epp.util.EPPEnv;
 import com.verisign.epp.util.EPPEnvException;
 import com.verisign.epp.util.EPPEnvSingle;
 
 /**
- * The <code>Server</code> class is responsible for reading the config file,
+ * The {@code Server} class is responsible for reading the config file,
  * instantiating an implementation of a ServerSocket (Plain or SSL), and
- * specifying the <code>ServerEventHandler</code> class that will be
- * instantiated with each new client connection. <br>
- * <br>
- *
- * @author $Author: jim $
- * @version $Revision: 1.2 $
+ * specifying the {@code ServerEventHandler} class that will be instantiated
+ * with each new client connection.
  */
 public class Server {
 	/** Default port to Listen on */
@@ -63,16 +52,6 @@ public class Server {
 	/** Category for logging */
 	private static Logger cat = LoggerFactory.getLogger(Server.class);
 
-	/**
-	 * Supported mappings. Be sure that the EPPCodec is initialized with some or
-	 * all of these. See the initializeCodec() method here for details.
-	 */
-	/** The number of connections to this server */
-	private int connection_count = 0;
-
-	/** The port this server listens for connections on */
-	private int port;
-
 	/**
 	 * Construct a Server instance
 	 *
@@ -86,9 +65,6 @@ public class Server {
 
 			env.initialize(configFileName);
 
-			// Initialize the server connection factory
-			EPPSrvFactorySingle theFactory = EPPSrvFactorySingle.getInstance();
-
 			// Initialize the dispatcher
 			initializeDispatcher();
 
@@ -97,17 +73,6 @@ public class Server {
 
 			// Initialize the poll queue
 			initializePollQueue();
-
-			cat.info("EPP Server: Starting server...");
-			cat.info("EPP Server: Creating server socket...");
-
-			EPPServerCon theServer = theFactory.getEPPServer();
-			theServer.RunServer(new ClientConnectionHandler());
-		}
-		catch (EPPConException e) {
-			cat.error("EPP Server: Connection Exception: " + e);
-			e.printStackTrace();
-			System.exit(1);
 		}
 		catch (EPPEnvException e) {
 			e.printStackTrace();
@@ -119,7 +84,6 @@ public class Server {
 		}
 	}
 
-
 	/**
 	 * Initialize the poll handler based on the EPP.PollHandlers,
 	 */
@@ -127,13 +91,13 @@ public class Server {
 		EPPPollQueueMgr thePollQueue = EPPPollQueueMgr.getInstance();
 
 		try {
-			Vector handlerClasses = EPPEnv.getPollHandlers();
+			Vector<String> handlerClasses = EPPEnv.getPollHandlers();
 
 			if (handlerClasses != null) {
-				Enumeration e = handlerClasses.elements();
+				Enumeration<String> e = handlerClasses.elements();
 
 				while (e.hasMoreElements()) {
-					String handlerClassName = (String) e.nextElement();
+					String handlerClassName = e.nextElement();
 					Class handlerClass = Class.forName(handlerClassName);
 
 					// register poll handler
@@ -141,41 +105,20 @@ public class Server {
 					cat.info("Successfully loaded poll handler: " + handlerClass.getName());
 				}
 
-				// end while
 			}
 
-			// end if (handlerClasses != null)
-		}
-
-		// end try
-		catch (EPPEnvException e) {
-			cat.error("Couldn't initialize the environment", e);
-			System.exit(1);
-		}
-		catch (InstantiationException e) {
-			cat.error("Couldn't instantiate one of the specified server poll handlers", e);
-			System.exit(1);
-		}
-		catch (IllegalAccessException e) {
-			cat.error("Couldn't instantiate one of the specified server poll handlers"
-			      + "\n The class or initializer is not accessible", e);
-			System.exit(1);
-		}
-		catch (ClassNotFoundException e) {
-			cat.error("Couldn't instantiate one of the poll handlers listed in the conf file", e);
-			System.exit(1);
 		}
 		catch (Exception e) {
-			cat.error("General exception in initializePollQueue:", e);
+			cat.error("EPP Server couldn't initialize the environment:" + e);
 			System.exit(1);
 		}
 	}
 
 	/**
-	 * Initializes <code>Server</code>'s dispatcher to handle the commmands
-	 * defined by the supported EPP mappings. At this point we also get the list
-	 * of Command Response extensions class names from the epp.config file and
-	 * add the CommandResponseextension classes to the EPPExtFaactory
+	 * Initializes {@code Server}'s dispatcher to handle the commands defined by
+	 * the supported EPP mappings. At this point we also get the list of Command
+	 * Response extensions class names from the epp.config file and add the
+	 * CommandResponseextension classes to the EPPExtFaactory
 	 */
 	public void initializeDispatcher() {
 		/**
@@ -187,7 +130,7 @@ public class Server {
 
 		try {
 
-			EPPFactory factory = EPPFactory.getInstance();
+			EPPFactory theFactory = EPPFactory.getInstance();
 
 			/**
 			 * Add the command response level extensions to the extension factories
@@ -195,14 +138,14 @@ public class Server {
 			 * can be done by adding the command response level extensions to the
 			 * EPPFactories method addExtFactory
 			 */
-			Vector commandExts = EPPEnv.getCmdResponseExtensions();
+			Vector<String> commandExts = EPPEnv.getCmdResponseExtensions();
 
 			if ((commandExts != null) && commandExts.elements().hasMoreElements()) {
 				for (int i = 0; i < commandExts.size(); i++) {
-					String commandExtensionClassName = (String) commandExts.elementAt(i);
+					String commandExtensionClassName = commandExts.elementAt(i);
 
 					try {
-						factory.addExtFactory(commandExtensionClassName);
+						theFactory.addExtFactory(commandExtensionClassName);
 					}
 					catch (EPPCodecException ex) {
 						cat.error(
@@ -222,14 +165,14 @@ public class Server {
 			 * can be done by adding the object mapping level extensions to the
 			 * EPPFactories method addMapFactory
 			 */
-			Vector mapFactories = EPPEnv.getMapFactories();
+			Vector<String> theMapFactories = EPPEnv.getMapFactories();
 
-			if ((mapFactories != null) && mapFactories.elements().hasMoreElements()) {
-				for (int i = 0; i < mapFactories.size(); i++) {
-					String mapFactoryClassName = (String) mapFactories.elementAt(i);
+			if ((theMapFactories != null) && theMapFactories.elements().hasMoreElements()) {
+				for (int i = 0; i < theMapFactories.size(); i++) {
+					String mapFactoryClassName = theMapFactories.elementAt(i);
 
 					try {
-						factory.addMapFactory(mapFactoryClassName);
+						theFactory.addMapFactory(mapFactoryClassName);
 					}
 					catch (EPPCodecException ex) {
 						cat.error("Couldn't load the Map Factory " + mapFactoryClassName + ":" + ex);
@@ -242,11 +185,11 @@ public class Server {
 
 			}
 
-			Vector handlerClasses = EPPEnv.getServerEventHandlers();
-			Enumeration e = handlerClasses.elements();
+			Vector<String> theServerEventHandlers = EPPEnv.getServerEventHandlers();
+			Enumeration<String> e = theServerEventHandlers.elements();
 
 			while (e.hasMoreElements()) {
-				String handlerClassName = (String) e.nextElement();
+				String handlerClassName = e.nextElement();
 				Class handlerClass = Class.forName(handlerClassName);
 				theDispatcher.registerHandler(
 				      (com.verisign.epp.framework.EPPEventHandler) handlerClass.getDeclaredConstructor().newInstance());
@@ -302,23 +245,8 @@ public class Server {
 				theDispatcher.setAssembler(new EPPXMLAssembler());
 			}
 		}
-		catch (InstantiationException e) {
-			cat.error("Couldn't instantiate the specified Server Assembler class. Check class name "
-			      + "\n and environment CLASSPATH:", e);
-			System.exit(1);
-		}
-		catch (IllegalAccessException e) {
-			cat.error("Couldn't instantiate the specified Server Assembler class. Check class name"
-			      + "\n and CLASSPATH envrionment variable. The class or initializer is not accessible:", e);
-			System.exit(1);
-		}
-		catch (ClassNotFoundException e) {
-			cat.error("Couldn't instantiate the specified Server Assembler class. Check class name "
-			      + "\n and environment CLASSPATH:", e);
-			System.exit(1);
-		}
 		catch (Exception e) {
-			cat.error("General exception in initializeDispatcher: ", e);
+			cat.error("EPP Server Initialization Exception: " + e);
 			System.exit(1);
 		}
 
@@ -330,17 +258,63 @@ public class Server {
 	}
 
 	/**
-	 * Runs the Server
+	 * Runs the EPP over TCP (EoT) Stub Server
+	 */
+	private void run() {
+		// Initialize the server connection factory
+		EPPSrvFactorySingle theFactory = EPPSrvFactorySingle.getInstance();
+
+		cat.info("EPP Server: Starting server...");
+
+		EPPServerCon theServer;
+		try {
+			theServer = theFactory.getEPPServer();
+			theServer.RunServer(new ClientConnectionHandler());
+		}
+		catch (Exception e) {
+			cat.error("EPP Server: Run Exception: " + e);
+			e.printStackTrace();
+			System.exit(1);
+		}
+	}
+
+	/**
+	 * Runs the EPP Stub Server Server with the usage:<br>
+	 * java Server [-help|&lt;config-file&gt;]<br>
+	 *
+	 * <pre>
+	 *    -help Gets the help
+	 *    &lt;config-file&gt; EPP configuration file, with default of "epp.config"
+	 * </pre>
 	 *
 	 * @param args
-	 *           The command line argument should be the epp.config file
+	 *           Command line arguments
 	 */
 	public static void main(String[] args) {
-		if (args.length != 1) {
-			System.out.println("Usage: java Server <config-file>");
+		String theConfigFile = "epp.config";
+
+		if (args.length == 1) {
+
+			if (args[0].equalsIgnoreCase("-help")) {
+				System.out.println("Usage: java Server [-help|<config-file>]");
+				System.out.println("Executes the EPP over TCP (EoT) Stub Server");
+				System.out.println("\t-help gets this help");
+				System.out.println("\t<config-file> EPP SDK configuration settings, with default of \"epp.config\"");
+				System.exit(0);
+
+			}
+			theConfigFile = args[0];
+		}
+		else if (args.length > 1) {
+			System.out.println("Usage: java Server [-help|<config-file>]");
+			System.out.println("Executes the EPP over TCP (EoT) Stub Server");
+			System.out.println("\t-help gets this help");
+			System.out.println("\t<config-file> EPP SDK configuration settings, with default of \"epp.config\"");
 			System.exit(1);
 		}
 
-		Server svr = new Server(args[0]);
+		Server theServer = new Server(theConfigFile);
+		theServer.run();
 	}
+
 }
