@@ -34,15 +34,12 @@ import javax.net.ssl.SSLSocket;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-
-
 /**
  * Server thread for processing a new client connection.
  */
 public class EPPServerThread extends Thread {
 	/** Category for logging */
-	    private static Logger cat = LoggerFactory.getLogger(EPPServerThread.class);
-	      
+	private static Logger cat = LoggerFactory.getLogger(EPPServerThread.class);
 
 	/** Client socket associated with thread */
 	private Socket socket = null;
@@ -80,10 +77,15 @@ public class EPPServerThread extends Thread {
 				@Override
 				public void handshakeCompleted(HandshakeCompletedEvent aEvent) {
 					try {
+						X509Certificate thePeerCert = (X509Certificate) aEvent.getPeerCertificates()[0];
+						X509Certificate theRootCert = (X509Certificate) aEvent
+						      .getPeerCertificates()[aEvent.getPeerCertificates().length - 1];
 						cat.debug("Server SSL Handshake" + ": Cipher = " + aEvent.getCipherSuite() + ": Protocol = "
-						      + aEvent.getSession().getProtocol() + ": Peer = "
-						      + aEvent.getSession().getPeerPrincipal().getName() + ": Issuer = "
-						      + ((X509Certificate) aEvent.getPeerCertificates()[0]).getIssuerDN().getName());
+						      + aEvent.getSession().getProtocol() + ": Peer (name, serial #, issuer) = ("
+						      + thePeerCert.getIssuerX500Principal().getName() + "," + thePeerCert.getSerialNumber() + ","
+						      + thePeerCert.getIssuerX500Principal().getName() + ")" + ": Root (name, serial #) = ("
+						      + thePeerCert.getIssuerX500Principal().getName() + "," + thePeerCert.getSerialNumber() + ","
+						      + thePeerCert.getIssuerX500Principal().getName() + ")");
 					}
 					catch (SSLPeerUnverifiedException e) {
 						// ignore
