@@ -33,46 +33,49 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.Random;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.verisign.epp.transport.EPPConException;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EPPEnv;
 
 /**
  * EPP plain client socket connection that goes through the Apache server
  * mod_proxy. The interface is exactly the same as EPPPlainClientSocket, except
- * one additional configuration properties that defines the {@link EPPProxyServersLocator} 
- * class that's used to get the list of proxy servers to connect through.  The 
- * <code>EPPProxyServersLocator</code> configuration property defines the location class.
- * Additional configuration properties might be required including:<br>
- * <br><ul>
- * <li><code>EPP.ProxyServers</code> - Defines the list of proxy servers when 
- * <code>EPPProxyServersLocator</code> is set to <code>com.verisign.epp.transport.client.EPPConfigProxyServersLocator</code>.
- * <li><code>EPP.ProxyServersRandomize</code> is set to <code>true</code> to enable 
- * randomization of the proxy servers to attempt to connect through and <code>false</code> otherwise.  
- * The default setting is <code>true</code> if <code>EPP.ProxyServersRandomize</code> is not set.
+ * one additional configuration properties that defines the
+ * {@link EPPProxyServersLocator} class that's used to get the list of proxy
+ * servers to connect through. The <code>EPPProxyServersLocator</code>
+ * configuration property defines the location class. Additional configuration
+ * properties might be required including:<br>
+ * <br>
+ * <ul>
+ * <li><code>EPP.ProxyServers</code> - Defines the list of proxy servers when
+ * <code>EPPProxyServersLocator</code> is set to
+ * <code>com.verisign.epp.transport.client.EPPConfigProxyServersLocator</code>.
+ * <li><code>EPP.ProxyServersRandomize</code> is set to <code>true</code> to
+ * enable randomization of the proxy servers to attempt to connect through and
+ * <code>false</code> otherwise. The default setting is <code>true</code> if
+ * <code>EPP.ProxyServersRandomize</code> is not set.
  * </ul>
  * <br>
- * The {@link EPPProxyServersLocator} is a static attribute for getting
- * the list of proxy servers connect through.  By default in the constructor 
- * the {@link EPPProxyServersLocator} is set based on the <code>EPPProxyServersLocator</code> 
- * configuration property.  If additional initialization is required for the 
- * {@link EPPProxyServersLocator} used, then the {@link #setLocator(EPPProxyServersLocator)} 
- * should be called prior to instantiating an instance of <code>EPPPlainProxyClientSocket</code> 
+ * The {@link EPPProxyServersLocator} is a static attribute for getting the list
+ * of proxy servers connect through. By default in the constructor the
+ * {@link EPPProxyServersLocator} is set based on the
+ * <code>EPPProxyServersLocator</code> configuration property. If additional
+ * initialization is required for the {@link EPPProxyServersLocator} used, then
+ * the {@link #setLocator(EPPProxyServersLocator)} should be called prior to
+ * instantiating an instance of <code>EPPPlainProxyClientSocket</code>
  * indirectly via the <code>EPPSession</code>.
  */
 public class EPPPlainProxyClientSocket extends EPPPlainClientSocket {
 
-	/** Log4j category for logging */
-	private static Logger cat = Logger.getLogger(
-			EPPPlainProxyClientSocket.class.getName(), EPPCatFactory
-					.getInstance().getFactory());
+	/** Category for logging */
+	private static Logger cat = LoggerFactory.getLogger(EPPPlainProxyClientSocket.class);
 
 	/**
 	 * List of {@link EPPProxyServer} instances creating from parsing the
-	 * EPP.ProxyServers configuration property by {@link
-	 * ProxyServer.decodeConfig(String)}.
+	 * EPP.ProxyServers configuration property by
+	 * {@link ProxyServer.decodeConfig(String)}.
 	 */
 	private List proxyServers;
 
@@ -93,7 +96,7 @@ public class EPPPlainProxyClientSocket extends EPPPlainClientSocket {
 	 * configuration property.
 	 * 
 	 * @throws EPPConException
-	 *             Error creating <code>EPPSSLProxyClientSocket</code> instance.
+	 *            Error creating <code>EPPSSLProxyClientSocket</code> instance.
 	 */
 	public EPPPlainProxyClientSocket() throws EPPConException {
 		super();
@@ -105,36 +108,30 @@ public class EPPPlainProxyClientSocket extends EPPPlainClientSocket {
 			// Locator not previously instantiated?
 			if (EPPPlainProxyClientSocket.locator == null) {
 
-				String theProxyServerLocatorProp = EPPEnv
-						.getProxyServerLocator();
+				String theProxyServerLocatorProp = EPPEnv.getProxyServerLocator();
 
 				Class locatorClass = Class.forName(theProxyServerLocatorProp);
-				if (!EPPProxyServersLocator.class
-						.isAssignableFrom(locatorClass)) {
-					throw new EPPConException(theProxyServerLocatorProp
-							+ " does not implement EPPProxyServersLocator");
+				if (!EPPProxyServersLocator.class.isAssignableFrom(locatorClass)) {
+					throw new EPPConException(theProxyServerLocatorProp + " does not implement EPPProxyServersLocator");
 				}
 
-				EPPPlainProxyClientSocket.locator = (EPPProxyServersLocator) locatorClass
-						.getDeclaredConstructor().newInstance();
+				EPPPlainProxyClientSocket.locator = (EPPProxyServersLocator) locatorClass.getDeclaredConstructor()
+				      .newInstance();
 			}
 
-			this.proxyServers = EPPPlainProxyClientSocket.locator
-					.getProxyServers();
+			this.proxyServers = EPPPlainProxyClientSocket.locator.getProxyServers();
 
 			this.proxyServersRandomize = EPPEnv.getProxyServersRandomize();
 		}
 		catch (Exception ex) {
 			cat.error("Connection Failed Due to : " + ex.getMessage(), ex);
 
-			throw new EPPConException("Connection Failed Due to : "
-					+ ex.getMessage());
+			throw new EPPConException("Connection Failed Due to : " + ex.getMessage());
 		}
 
 		// No proxy servers?
 		if (this.proxyServers.size() == 0) {
-			throw new EPPConException(
-					"No proxy servers defined by EPP.ProxyServers configuration property");
+			throw new EPPConException("No proxy servers defined by EPP.ProxyServers configuration property");
 		}
 
 		cat.debug("EPPPlainProxyClientSocket(): exit");
@@ -147,7 +144,7 @@ public class EPPPlainProxyClientSocket extends EPPPlainClientSocket {
 	 * through the proxy server.
 	 * 
 	 * @exception EPPConException
-	 *                Error with SSL connection throw the Apache proxy server
+	 *               Error with SSL connection throw the Apache proxy server
 	 */
 	public void initialize() throws EPPConException {
 		cat.debug("initialize(): start");
@@ -159,8 +156,7 @@ public class EPPPlainProxyClientSocket extends EPPPlainClientSocket {
 		Socket theSocket = null;
 		EPPProxyServer theCurrProxy = null;
 
-		cat.debug("initialize(): proxy server list size = "
-				+ theProxyList.size());
+		cat.debug("initialize(): proxy server list size = " + theProxyList.size());
 
 		// Not connected and more proxy servers
 		while (!theConnectedToProxy && theProxyList.size() != 0) {
@@ -175,17 +171,16 @@ public class EPPPlainProxyClientSocket extends EPPPlainClientSocket {
 				theCurrProxyIndex = 0;
 			}
 
-			cat.debug("initialize(): proxy server selected index "
-					+ theCurrProxyIndex + " of " + theProxyList.size()
-					+ " servers");
+			cat.debug("initialize(): proxy server selected index " + theCurrProxyIndex + " of " + theProxyList.size()
+			      + " servers");
 
 			theCurrProxy = (EPPProxyServer) theProxyList.get(theCurrProxyIndex);
 			theProxyList.remove(theCurrProxyIndex);
 
 			cat.debug("initialize(): proxy server = " + theCurrProxy);
 
-			InetSocketAddress theSocketAddress = new InetSocketAddress(
-					theCurrProxy.getServerName(), theCurrProxy.getServerPort());
+			InetSocketAddress theSocketAddress = new InetSocketAddress(theCurrProxy.getServerName(),
+			      theCurrProxy.getServerPort());
 
 			theSocket = new Socket();
 
@@ -193,15 +188,12 @@ public class EPPPlainProxyClientSocket extends EPPPlainClientSocket {
 
 				// Want to specify the client host?
 				if (super.getClientHostName() != null) {
-					cat.debug("initialize(): Binding to client address = "
-							+ super.getClientHostName());
-					InetSocketAddress theClientSocketAddress = new InetSocketAddress(
-							super.getClientHostName(), 0);
+					cat.debug("initialize(): Binding to client address = " + super.getClientHostName());
+					InetSocketAddress theClientSocketAddress = new InetSocketAddress(super.getClientHostName(), 0);
 					theSocket.bind(theClientSocketAddress);
 				}
 
-				cat.debug("initialize(): Attempting to connect proxy server = "
-						+ theCurrProxy);
+				cat.debug("initialize(): Attempting to connect proxy server = " + theCurrProxy);
 
 				theSocket.connect(theSocketAddress, super.getConTimeout());
 
@@ -212,13 +204,11 @@ public class EPPPlainProxyClientSocket extends EPPPlainClientSocket {
 
 				String theLine;
 
-				theLine = "CONNECT " + super.getHostName() + ":"
-						+ super.getPortNumber() + " HTTP/1.1\r\n";
+				theLine = "CONNECT " + super.getHostName() + ":" + super.getPortNumber() + " HTTP/1.1\r\n";
 				cat.debug("Proxy Server Send [" + theLine + "]");
 				theStream.write(theLine.getBytes());
 
-				theLine = "Host: " + super.getHostName() + ":"
-						+ super.getPortNumber() + "\r\n";
+				theLine = "Host: " + super.getHostName() + ":" + super.getPortNumber() + "\r\n";
 				cat.debug("Proxy Server Send [" + theLine + "]");
 				theStream.write(theLine.getBytes());
 
@@ -228,8 +218,7 @@ public class EPPPlainProxyClientSocket extends EPPPlainClientSocket {
 
 				theStream.flush();
 
-				BufferedReader theInputStream = new BufferedReader(
-						new InputStreamReader(theSocket.getInputStream()));
+				BufferedReader theInputStream = new BufferedReader(new InputStreamReader(theSocket.getInputStream()));
 
 				// Validate the connection to Proxy Server and read all output
 				int theLineNum = 1;
@@ -239,15 +228,12 @@ public class EPPPlainProxyClientSocket extends EPPPlainClientSocket {
 
 					// Validate the connection through the Proxy Server
 					if (theLineNum == 1) {
-						if (theLine != null
-								&& (theLine.indexOf("Connection Established") != -1)) {
+						if (theLine != null && (theLine.indexOf("Connection Established") != -1)) {
 							theConnectedToProxy = true;
-							cat.info("Proxy Server " + theCurrProxy
-									+ " TCP connection established");
+							cat.info("Proxy Server " + theCurrProxy + " TCP connection established");
 						}
 						else {
-							cat.info("Proxy Server " + theCurrProxy
-									+ " TCP connection failed: " + theLine);
+							cat.info("Proxy Server " + theCurrProxy + " TCP connection failed: " + theLine);
 							theSocket.close();
 							break;
 						}
@@ -259,8 +245,7 @@ public class EPPPlainProxyClientSocket extends EPPPlainClientSocket {
 
 			}
 			catch (IOException ex) {
-				cat.info("Proxy Server " + theCurrProxy
-						+ " TCP connection failed: " + ex);
+				cat.info("Proxy Server " + theCurrProxy + " TCP connection failed: " + ex);
 			}
 
 		}
@@ -277,25 +262,22 @@ public class EPPPlainProxyClientSocket extends EPPPlainClientSocket {
 			super.setConnected(true);
 		}
 		catch (IOException ex) {
-			cat.error("Failed getting streams from SSL socket: "
-					+ ex.getMessage());
-			throw new EPPConException(
-					"Failed getting streams from SSL socket: "
-							+ ex.getMessage());
+			cat.error("Failed getting streams from SSL socket: " + ex.getMessage());
+			throw new EPPConException("Failed getting streams from SSL socket: " + ex.getMessage());
 		}
 
 		cat.debug("initialize(): exit");
 	}
-	
+
 	/**
 	 * Gets the current {@link EPPProxyServersLocator} used by
 	 * <code>EPPPlainProxyClientSocket</code>. The locator is a static / global
-	 * setting for creating socket connections to define the set of proxy
-	 * servers to connect through. The locator set can dynamically change the
-	 * proxy servers to connect through. If not define before an
-	 * <code>EPPPlainProxyClientSocket</code> is instantiated, the default locator
-	 * is defined by the <code>EPP.ProxyServersLocator</code> configuration
-	 * property.
+	 * setting for creating socket connections to define the set of proxy servers
+	 * to connect through. The locator set can dynamically change the proxy
+	 * servers to connect through. If not define before an
+	 * <code>EPPPlainProxyClientSocket</code> is instantiated, the default
+	 * locator is defined by the <code>EPP.ProxyServersLocator</code>
+	 * configuration property.
 	 * 
 	 * @return {@link EPPProxyServersLocator} instance if defined;
 	 *         <code>null</code> otherwise.
@@ -307,21 +289,20 @@ public class EPPPlainProxyClientSocket extends EPPPlainClientSocket {
 	/**
 	 * Sets the {@link EPPProxyServersLocator} to use when getting the list of
 	 * proxy servers to connect through. If not define before an
-	 * <code>EPPPlainProxyClientSocket</code> is instantiated, the default locator
-	 * is defined by the <code>EPP.ProxyServersLocator</code> configuration
-	 * property, so if a {@link EPPProxyServersLocator} objects needs further
-	 * initialized outside the default constructor,
+	 * <code>EPPPlainProxyClientSocket</code> is instantiated, the default
+	 * locator is defined by the <code>EPP.ProxyServersLocator</code>
+	 * configuration property, so if a {@link EPPProxyServersLocator} objects
+	 * needs further initialized outside the default constructor,
 	 * {@link #setLocator(EPPProxyServersLocator)} must be called before
 	 * <code>EPPPlainProxyClientSocket</code> is instantiated indirectly in
 	 * creating an <code>EPPSession</code>.
 	 * 
 	 * @param aLocator
-	 *            {@link EPPProxyServersLocator} instance to use to get the list
-	 *            of proxy servers to connect through.
+	 *           {@link EPPProxyServersLocator} instance to use to get the list
+	 *           of proxy servers to connect through.
 	 */
 	public static void setLocator(EPPProxyServersLocator aLocator) {
 		locator = aLocator;
 	}
 
-
 }
