@@ -35,11 +35,11 @@ import javax.net.ssl.SSLSocketFactory;
 import javax.net.ssl.TrustManager;
 import javax.net.ssl.TrustManagerFactory;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.verisign.epp.exception.EPPException;
 import com.verisign.epp.transport.EPPConException;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EPPEnv;
 
 /**
@@ -76,8 +76,8 @@ import com.verisign.epp.util.EPPEnv;
 public class EPPSSLImpl {
 
 	/** Used for logging */
-	private static Logger logger = Logger.getLogger(EPPSSLImpl.class.getName(),
-			EPPCatFactory.getInstance().getFactory());
+	private static Logger logger = LoggerFactory.getLogger(EPPSSLImpl.class);
+			
 
 	/**
 	 * SSL context information
@@ -202,7 +202,7 @@ public class EPPSSLImpl {
 
 		logger.info("initialize(EPPSSLConfig): Config = " + aConfig);
 
-		EPPSSLContext theContext = new EPPSSLContext();
+		EPPSSLContext theContext = new EPPSSLContext(aConfig);
 
 		KeyManagerFactory theKeyStoreFactory = null;
 		KeyStore theKeyStore = null;
@@ -448,6 +448,11 @@ public class EPPSSLImpl {
 		theContext.setSSLEnabledProtocols(aConfig.getSSLEnabledProtocols());
 		theContext
 				.setSSLEnabledCipherSuites(aConfig.getSSLEnabledCipherSuites());
+		
+		// Disable SSL host name verification?
+		if (aConfig.isSSLDisableHostnameVerification()) {
+			System.setProperty("jdk.internal.httpclient.disableHostnameVerification", Boolean.TRUE.toString());
+		}
 
 		logger.debug("initialize(EPPSSLConfig): exit");
 		return theContext;
@@ -484,6 +489,7 @@ public class EPPSSLImpl {
 
 		theConfig.setSSLEnabledProtocols(EPPEnv.getSSLEnabledProtocols());
 		theConfig.setSSLEnabledCipherSuites(EPPEnv.getSSLEnabledCipherSuites());
+		theConfig.setSSLDisableHostnameVerification(EPPEnv.getSSLDisableHostnameVerification());
 
 		context = initialize(theConfig);
 
