@@ -20,6 +20,7 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 
 package com.verisign.epp.util;
 
+import java.net.http.HttpClient;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.StringTokenizer;
@@ -209,6 +210,58 @@ public abstract class EPPEnv extends Environment {
 		return Integer.valueOf(st).intValue();
 	}
 
+	/**
+	 * Returns the HTTP version to use, with the default being HTTP/2 ("2").
+	 *
+	 * @return String value for the HTTP version, with the possible set of values
+	 *         being "1.1" for HTTP/1.1, "2" for HTTP/2, and future "3" for
+	 *         HTTP/3.
+	 * @exception EPPEnvException
+	 *               The &quot;EPP.HttpVersion&quot; property is invalid.
+	 */
+	public static String getHttpVersion() throws EPPEnvException {
+		String thePropValue = Environment.getOption("EPP.HttpVersion");
+		String theVersion = "2"; // Default to HTTP/2
+
+		if (thePropValue != null) {
+
+			if (!thePropValue.equals("1.1") && !thePropValue.equals("2")) {
+				throw new EPPEnvException("Invalid EPP.HttpVersion value of " + thePropValue);
+			}
+
+			theVersion = thePropValue;
+		}
+
+		return theVersion;
+	}	
+
+	/**
+	 * Returns the HTTP server scheme to use, with the options being "http" and
+	 * "https".
+	 *
+	 * @return The HTTP server scheme to use, with the options being "http" or
+	 *         "https".
+	 * @exception EPPEnvException
+	 *               The &quot;EPP.HttpServerScheme&quot; property does not
+	 *               exist.
+	 */
+	public static String getHttpServerScheme() throws EPPEnvException {
+		String st = null;
+
+		try {
+			st = Environment.getEnv("EPP.HttpServerScheme");
+
+			if (!st.equals("http") && !st.equals("https")) {
+				throw new EPPEnvException("EPP.HttpServerScheme value is invalid: " + st);
+			}
+		}
+		catch (EnvException myException) {
+			throw new EPPEnvException("EPP Environment Exception : " + myException.getMessage());
+		}
+
+		return st;
+	}
+
 	/**
 	 * Returns the connection timeout in number of milliseconds specified by the
 	 * &quot;EPP.ConTimeOut&quot; property in the config file.
@@ -388,8 +441,8 @@ public abstract class EPPEnv extends Environment {
 	 * @exception EPPEnvException
 	 *               Error with &quot;EPP.MapFactories&quot; property.
 	 */
-	public static Vector getMapFactories() throws EPPEnvException {
-		Vector ret = new Vector();
+	public static Vector<String> getMapFactories() throws EPPEnvException {
+		Vector<String> ret = new Vector<String>();
 
 		try {
 			String setting = Environment.getEnv("EPP.MapFactories");
@@ -397,7 +450,7 @@ public abstract class EPPEnv extends Environment {
 			StringTokenizer tokenizer = new StringTokenizer(setting);
 
 			while (tokenizer.hasMoreElements()) {
-				ret.addElement(tokenizer.nextElement());
+				ret.addElement((String) tokenizer.nextElement());
 			}
 		}
 		catch (EnvException myException) {
@@ -417,8 +470,8 @@ public abstract class EPPEnv extends Environment {
 	 * @exception EPPEnvException
 	 *               Error with &quot;EPP.ProtocolExtensions&quot; property.
 	 */
-	public static Vector getProtocolExtensions() throws EPPEnvException {
-		Vector ret = new Vector();
+	public static Vector<String> getProtocolExtensions() throws EPPEnvException {
+		Vector<String> ret = new Vector<String>();
 
 		try {
 			String setting = Environment.getEnv("EPP.ProtocolExtensions");
@@ -426,7 +479,7 @@ public abstract class EPPEnv extends Environment {
 			StringTokenizer tokenizer = new StringTokenizer(setting);
 
 			while (tokenizer.hasMoreElements()) {
-				ret.addElement(tokenizer.nextElement());
+				ret.addElement((String) tokenizer.nextElement());
 			}
 		}
 		catch (EnvException myException) {
@@ -446,8 +499,8 @@ public abstract class EPPEnv extends Environment {
 	 * @exception EPPEnvException
 	 *               Error with &quot;EPP.CmdRspExtensions&quot; property.
 	 */
-	public static Vector getCmdResponseExtensions() throws EPPEnvException {
-		Vector ret = new Vector();
+	public static Vector<String> getCmdResponseExtensions() throws EPPEnvException {
+		Vector<String> ret = new Vector<String>();
 
 		try {
 			String setting = Environment.getEnv("EPP.CmdRspExtensions");
@@ -455,7 +508,7 @@ public abstract class EPPEnv extends Environment {
 			StringTokenizer tokenizer = new StringTokenizer(setting);
 
 			while (tokenizer.hasMoreElements()) {
-				ret.addElement(tokenizer.nextElement());
+				ret.addElement((String) tokenizer.nextElement());
 			}
 		}
 		catch (EnvException myException) {
@@ -475,8 +528,8 @@ public abstract class EPPEnv extends Environment {
 	 * @exception EPPEnvException
 	 *               Error with &quot;EPP.ServerEventHandlers&quot; property.
 	 */
-	public static Vector getServerEventHandlers() throws EPPEnvException {
-		Vector ret = new Vector();
+	public static Vector<String> getServerEventHandlers() throws EPPEnvException {
+		Vector<String> ret = new Vector<String>();
 
 		try {
 			String setting = Environment.getEnv("EPP.ServerEventHandlers");
@@ -484,7 +537,7 @@ public abstract class EPPEnv extends Environment {
 			StringTokenizer tokenizer = new StringTokenizer(setting);
 
 			while (tokenizer.hasMoreElements()) {
-				ret.addElement(tokenizer.nextElement());
+				ret.addElement((String) tokenizer.nextElement());
 			}
 		}
 		catch (EnvException myException) {
@@ -630,6 +683,24 @@ public abstract class EPPEnv extends Environment {
 		return theSSLEnabledCipherSuites;
 	}
 
+	/**
+	 * Gets the option of disabling the host name verification. The default value
+	 * of {@code false} if not defined with the
+	 * "EPP.SSLDisableHostnameVerification" config property.
+	 * 
+	 * @return Disable the SSL host name verification?
+	 */
+	public static boolean getSSLDisableHostnameVerification() {
+		boolean theDisableHostnameVerification = false;
+		String theValue = Environment.getOption("EPP.SSLDisableHostnameVerification");
+		// Property is defined?
+		if ((theValue != null) && (theValue.length() != 0)) {
+			theDisableHostnameVerification = Boolean.valueOf(theValue);
+		}
+
+		return theDisableHostnameVerification;
+	}
+
 	/**
 	 * SSL Socket Option. Returns the SSL Passphrase
 	 *
@@ -736,8 +807,8 @@ public abstract class EPPEnv extends Environment {
 	 * @exception EPPEnvException
 	 *               Error with &quot;EPP.PollHandlers&quot; property.
 	 */
-	public static Vector getPollHandlers() throws EPPEnvException {
-		Vector ret = new Vector();
+	public static Vector<String> getPollHandlers() throws EPPEnvException {
+		Vector<String> ret = new Vector<String>();
 
 		try {
 			String setting = Environment.getEnv("EPP.PollHandlers");
@@ -745,7 +816,7 @@ public abstract class EPPEnv extends Environment {
 			StringTokenizer tokenizer = new StringTokenizer(setting);
 
 			while (tokenizer.hasMoreElements()) {
-				ret.addElement(tokenizer.nextElement());
+				ret.addElement((String) tokenizer.nextElement());
 			}
 		}
 		catch (EnvException myException) {
