@@ -43,12 +43,11 @@ import com.verisign.epp.framework.EPPAssemblerException;
 import com.verisign.epp.pool.transformer.EPPTransformerPool;
 
 /**
- * {@code EPPXMLStream} is a utility class for reading and writing EPP
- * messages to/from streams. DOM Document are read and written to the streams.
- * An XML parser is required when reading from the stream. There is one
- * constructor that will create an XML parser per call to
- * {@code read(InputStream)} and one that will use a parser pool. Use of a
- * parser pool is recommended.
+ * {@code EPPXMLStream} is a utility class for reading and writing EPP messages
+ * to/from streams. DOM Document are read and written to the streams. An XML
+ * parser is required when reading from the stream. There is one constructor
+ * that will create an XML parser per call to {@code read(InputStream)} and one
+ * that will use a parser pool. Use of a parser pool is recommended.
  */
 public class EPPXMLStream {
 
@@ -81,7 +80,7 @@ public class EPPXMLStream {
 	private static EPPSendReceiveLogger sendReceiveLogger;
 
 	/** Category for logging */
-	    private static Logger cat = LoggerFactory.getLogger(EPPXMLStream.class);
+	private static Logger cat = LoggerFactory.getLogger(EPPXMLStream.class);
 
 	static {
 		// Initialize the Document Builder Factory
@@ -100,17 +99,17 @@ public class EPPXMLStream {
 				System.err.println("EPPXMLStream: EPP.MaxPacketSize property format error: " + ex);
 			}
 		}
-		
+
 		sendReceiveLogger = EPPEnv.getSendReceiveLogger();
 
 		cat.info("maxPacketSize = " + maxPacketSize);
 	}
 
 	/**
-	 * Default constructor for {@code EPPXMLStream}. When using this
-	 * constructor, a parser instance will be created on each call to
-	 * {@code read(InputStream)} and a transformer instance will be created
-	 * on each call to {@code write(Document,OutputStream)}. .
+	 * Default constructor for {@code EPPXMLStream}. When using this constructor,
+	 * a parser instance will be created on each call to
+	 * {@code read(InputStream)} and a transformer instance will be created on
+	 * each call to {@code write(Document,OutputStream)}. .
 	 */
 	public EPPXMLStream() {
 		this.byteArray = new EPPXMLByteArray();
@@ -118,10 +117,10 @@ public class EPPXMLStream {
 
 	/**
 	 * Construct {@code EPPXMLStream} to use a parser pool and a default
-	 * transformer pool. When using this
-	 * constructor, a parser instance will be checked out and checked in as needed
-	 * on each call to {@code read(InputStream)}. The {@link EPPTransformerPool} is used by default
-	 * for the transformer pool.
+	 * transformer pool. When using this constructor, a parser instance will be
+	 * checked out and checked in as needed on each call to
+	 * {@code read(InputStream)}. The {@link EPPTransformerPool} is used by
+	 * default for the transformer pool.
 	 * 
 	 * @param aParserPool
 	 *           Parser pool to use
@@ -132,17 +131,18 @@ public class EPPXMLStream {
 
 	/**
 	 * Construct {@code EPPXMLStream} to use a parser pool and a transformer
-	 * pool. When using this constructor, a
-	 * parser instance will be checked out and checked in as needed on each call to
-	 * one of the read methods and a transformer instance is checked out 
-	 * and checked in as needed on each call to one of the write methods. 
+	 * pool. When using this constructor, a parser instance will be checked out
+	 * and checked in as needed on each call to one of the read methods and a
+	 * transformer instance is checked out and checked in as needed on each call
+	 * to one of the write methods.
 	 * 
 	 * @param aParserPool
 	 *           Parser pool to use
 	 * @param aTransformerPool
 	 *           Transformer pool to use
 	 */
-	public EPPXMLStream(BaseObjectPool<? extends DocumentBuilder> aParserPool, BaseObjectPool<? extends Transformer> aTransformerPool) {
+	public EPPXMLStream(BaseObjectPool<? extends DocumentBuilder> aParserPool,
+	      BaseObjectPool<? extends Transformer> aTransformerPool) {
 		this.byteArray = new EPPXMLByteArray(aParserPool, aTransformerPool);
 	}
 
@@ -218,11 +218,11 @@ public class EPPXMLStream {
 	}
 
 	/**
-	 * Reads an EPP packet from the {@code aStream} parameter,
-	 * parses/validates it, and returns the associated DOM Document. The XML
-	 * parser is either created per call, or is retrieved from a parser pool when
-	 * {@code EPPXMLStream(GenericPoolManager)} is used. Use of a parser
-	 * pool is recommended.
+	 * Reads an EPP packet from the {@code aStream} parameter, parses/validates
+	 * it, and returns the associated DOM Document. The XML parser is either
+	 * created per call, or is retrieved from a parser pool when
+	 * {@code EPPXMLStream(GenericPoolManager)} is used. Use of a parser pool is
+	 * recommended.
 	 * 
 	 * @param aStream
 	 *           Input stream to read for an EPP packet.
@@ -256,8 +256,7 @@ public class EPPXMLStream {
 	}
 
 	/**
-	 * Decodes the passed in packet {@code byte[]} into a DOM
-	 * {@code Document}.
+	 * Decodes the passed in packet {@code byte[]} into a DOM {@code Document}.
 	 * 
 	 * @param aPacket
 	 *           Input packet to decode to DOM {@code Document}.
@@ -285,8 +284,8 @@ public class EPPXMLStream {
 	 * @param aMessage
 	 *           Message object associated with the packet that can be used for
 	 *           filtering the information written to the packet log. Passing
-	 *           {@code null} may not filter or may cause performance issues
-	 *           in filtering the log information.
+	 *           {@code null} may not filter or may cause performance issues in
+	 *           filtering the log information.
 	 * 
 	 * @throws IOException
 	 *            Error writing the packet to the output stream
@@ -325,9 +324,8 @@ public class EPPXMLStream {
 	 * @param aOutput
 	 *           Output stream to write to
 	 * @param aMessage
-	 *           {@code EPPMessage} associated with {@code aDoc} that
-	 *           is used for packet logging logic. Set to {@code null} if
-	 *           unavailable.
+	 *           {@code EPPMessage} associated with {@code aDoc} that is used for
+	 *           packet logging logic. Set to {@code null} if unavailable.
 	 * 
 	 * @exception EPPException
 	 *               Error writing to stream. It is recommended that the stream
@@ -361,6 +359,4 @@ public class EPPXMLStream {
 		cat.debug("write(Document, InputStream, EPPMessage): exit");
 	}
 
-}
-
-// End class EPPXMLStream
+}
\ No newline at end of file
