@@ -73,10 +73,6 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
  * information on the Apache Software Foundation, please see
  * <http://www.apache.org/>.
  */
-package com.verisign.epp.util;
-
-import java.lang.*;
-
 
 /**
  * format validation This class encodes/decodes hexadecimal data
@@ -129,7 +125,7 @@ public final class HexBin {
 	 * @return <code>true</code> if hex; <code>false</code> otherwise
 	 */
 	static boolean isHex(byte octect) {
-		//shall we ignore white space? JEFF??
+		// shall we ignore white space? JEFF??
 		return (hexNumberTable[octect] != -1);
 	}
 
@@ -163,7 +159,8 @@ public final class HexBin {
 	/**
 	 * DOCUMENT ME!
 	 *
-	 * @param isValidString DOCUMENT ME!
+	 * @param isValidString
+	 *           DOCUMENT ME!
 	 *
 	 * @return DOCUMENT ME!
 	 */
@@ -176,74 +173,72 @@ public final class HexBin {
 	}
 
 	/**
-	 * array of byte to encode
+	 * Encode binary data to Hex
 	 *
-	 * @param binaryData
+	 * @param aBinaryData
+	 *           Binary data to Hex encode
 	 *
-	 * @return return encode binary array
+	 * @return return Hex encoded array
 	 */
-	static public byte[] encode(byte[] binaryData) {
-		if (binaryData == null) {
+	static public byte[] encode(byte[] aBinaryData) {
+		if (aBinaryData == null) {
 			return null;
 		}
 
-		int    lengthData   = binaryData.length;
-		int    lengthEncode = lengthData * 2;
-		byte[] encodedData  = new byte[lengthEncode];
+		int lengthData = aBinaryData.length;
+		int lengthEncode = lengthData * 2;
+		byte[] encodedData = new byte[lengthEncode];
 
 		for (int i = 0; i < lengthData; i++) {
-			encodedData[i * 2]     = lookUpHexAlphabet[(binaryData[i] >> 4)
-									 & 0xf];
-			encodedData[(i * 2) + 1] = lookUpHexAlphabet[binaryData[i] & 0xf];
+			encodedData[i * 2] = lookUpHexAlphabet[(aBinaryData[i] >> 4) & 0xf];
+			encodedData[(i * 2) + 1] = lookUpHexAlphabet[aBinaryData[i] & 0xf];
 		}
 
 		return encodedData;
 	}
 
 	/**
-	 * DOCUMENT ME!
+	 * Decode Hex data to binary data
 	 *
-	 * @param binaryData DOCUMENT ME!
+	 * @param aHexData
+	 *           Hex data to Hex decode
 	 *
-	 * @return DOCUMENT ME!
+	 * @return return Hex decoded binary data
 	 */
-	static public byte[] decode(byte[] binaryData) {
-		if (binaryData == null) {
+	static public byte[] decode(byte[] aHexData) {
+		if (aHexData == null) {
 			return null;
 		}
 
-		int lengthData = binaryData.length;
+		int lengthData = aHexData.length;
 
 		if ((lengthData % 2) != 0) {
 			return null;
 		}
 
-		int    lengthDecode = lengthData / 2;
+		int lengthDecode = lengthData / 2;
 		byte[] decodedData = new byte[lengthDecode];
 
 		for (int i = 0; i < lengthDecode; i++) {
-			decodedData[i] =
-				(byte) (
-					(hexNumberTable[binaryData[i * 2]] << 4)
-					| hexNumberTable[binaryData[(i * 2) + 1]]
-				);
+			decodedData[i] = (byte) ((hexNumberTable[aHexData[i * 2]] << 4) | hexNumberTable[aHexData[(i * 2) + 1]]);
 		}
 
 		return decodedData;
 	}
 
 	/**
-	 * DOCUMENT ME!
+	 * Get length length of the Hex data
 	 *
-	 * @param hexData DOCUMENT ME!
+	 * @param aHexData
+	 *           DOCUMENT ME!
 	 *
-	 * @return DOCUMENT ME!
+	 * @return Length of Hex data if is Hex data; {@code -1} otherwise.
 	 */
-	static public int getDecodedDataLength(byte[] hexData) {
-		if (!isArrayByteHex(hexData)) {
+	static public int getDecodedDataLength(byte[] aHexData) {
+		if (!isArrayByteHex(aHexData)) {
 			return -1;
 		}
 
-		return hexData.length / 2;
+		return aHexData.length / 2;
 	}
 }
