@@ -30,10 +30,9 @@ import com.verisign.epp.codec.gen.EPPEncodeDecodeStats;
 import com.verisign.epp.codec.gen.EPPFactory;
 import com.verisign.epp.util.TestThread;
 
-import junit.framework.Assert;
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
+import org.junit.Assert;
+import org.junit.BeforeClass;
+import org.junit.Test;
 
 /**
  * Is a unit test of the com.verisign.epp.codec.syncext package. The unit test
@@ -44,32 +43,21 @@ import junit.framework.TestSuite;
  *
  * @author $Author: jim $
  */
-public class EPPSyncExtTst extends TestCase {
-	/**
-	 * Number of unit test iterations to run. This is set in
-	 * <code>EPPCodecTst.main</code>
-	 */
-	static private long numIterations = 1;
+public class EPPSyncExtTst {
+  /**
+   * Number of unit test iterations to run. This is set in
+   * <code>EPPCodecTst.main</code>
+   */
+  static private long numIterations = 1;
 
-	/**
-	 * Creates a new EPPSyncExtTst object.
-	 *
-	 * @param name DOCUMENT ME!
-	 */
-	public EPPSyncExtTst(String name) {
-		super(name);
-	}
-
-	// End EPPSyncExtTst(String)
-
-
-	public void testDomainUpdateCommandWithSyncExt() {
+  @Test
+  public void testDomainUpdateCommandWithSyncExt() {
 
         EPPCodecTst.printStart("testDomainUpdateCommandWithSyncExt");
 
         EPPDomainUpdateCmd theCommand =
             new EPPDomainUpdateCmd("example.com");
-        
+
         theCommand.setTransId("ABC-12345-XYZ");
 
 
@@ -77,7 +65,7 @@ public class EPPSyncExtTst extends TestCase {
        EPPSyncExtUpdate syncUpdate = new EPPSyncExtUpdate();
        syncUpdate.setMonth(Calendar.DECEMBER);
        syncUpdate.setDay(30);
- 
+
        theCommand.addExtension(syncUpdate);
 
         EPPEncodeDecodeStats commandStats =
@@ -85,11 +73,9 @@ public class EPPSyncExtTst extends TestCase {
 
         System.out.println(commandStats);
 
-        
-        
         theCommand =
             new EPPDomainUpdateCmd("example2.com");
-        
+
         theCommand.setTransId("ABC-12345-XYZ");
 
 
@@ -97,17 +83,17 @@ public class EPPSyncExtTst extends TestCase {
        syncUpdate = new EPPSyncExtUpdate();
        syncUpdate.setMonth(Calendar.JANUARY);
        syncUpdate.setDay(1);
- 
+
        theCommand.addExtension(syncUpdate);
 
        commandStats =
             EPPCodecTst.testEncodeDecode(theCommand);
 
         System.out.println(commandStats);
-        
+
         theCommand =
             new EPPDomainUpdateCmd("example3.com");
-        
+
         theCommand.setTransId("ABC-12345-XYZ");
 
 
@@ -122,117 +108,46 @@ public class EPPSyncExtTst extends TestCase {
             EPPCodecTst.testEncodeDecode(theCommand);
 
         System.out.println(commandStats);
-        
-        
-        
+
         EPPCodecTst.printEnd("testDomainUpdateCommandWithSyncExt");
     }
 
-	/**
-	 * JUNIT <code>setUp</code> method, which sets the default client Id to
-	 * "theRegistrar" and initializes the <code>EPPDomainMapFactory</code>
-	 * with the <code>EPPCodec</code>.
-	 */
-	protected void setUp() {
-	}
+  /**
+   * JUNIT <code>suite</code> static method, which returns the tests
+   * associated with <code>EPPSyncExtTst</code>.
+   */
+  @BeforeClass
+  public static void setup() {
+    EPPCodecTst.initEnvironment();
 
-	// End EPPSyncExtTst.setUp();
+    // iterations Property
+    String numIterProp = System.getProperty("iterations");
 
-	/**
-	 * JUNIT <code>tearDown</code>, which currently does nothing.
-	 */
-	protected void tearDown() {
-	}
-
-	// End EPPSyncExtTst.tearDown();
-
-	/**
-	 * JUNIT <code>suite</code> static method, which returns the tests
-	 * associated with <code>EPPSyncExtTst</code>.
-	 *
-	 * @return DOCUMENT ME!
-	 */
-	public static Test suite() {
-		EPPCodecTst.initEnvironment();
-
-		TestSuite suite = new TestSuite(EPPSyncExtTst.class);
-
-		// iterations Property
-		String numIterProp = System.getProperty("iterations");
-
-		if (numIterProp != null) {
-			numIterations = Integer.parseInt(numIterProp);
-		}
+    if (numIterProp != null) {
+      numIterations = Integer.parseInt(numIterProp);
+    }
 
 
-		// Add the EPPDomainMapFactory to the EPPCodec.
-		try {
-			EPPFactory.getInstance().addMapFactory("com.verisign.epp.codec.domain.EPPDomainMapFactory");
+    // Add the EPPDomainMapFactory to the EPPCodec.
+    try {
+      EPPFactory.getInstance().addMapFactory("com.verisign.epp.codec.domain.EPPDomainMapFactory");
             EPPFactory.getInstance().addExtFactory("com.verisign.epp.codec.syncext.EPPSyncExtFactory");
-		}
-		 catch (EPPCodecException e) {
-			Assert.fail("EPPCodecException adding EPPDomainMapFactory or EPPSyncExtFactory to EPPCodec: "
-						+ e);
-		}
-        return suite;
-	}
+    }
+     catch (EPPCodecException e) {
+      Assert.fail("EPPCodecException adding EPPDomainMapFactory or EPPSyncExtFactory to EPPCodec: "
+            + e);
+    }
+  }
 
-	// End EPPSyncExtTst.suite()
+  /**
+   * Sets the number of iterations to run per test.
+   *
+   * @param aNumIterations number of iterations to run per test
+   */
+  public static void setNumIterations(long aNumIterations) {
+    numIterations = aNumIterations;
+  }
 
-	/**
-	 * Unit test main, which accepts the following system property options:
-	 * <br>
-	 *
-	 * <ul>
-	 * <li>
-	 * iterations Number of unit test iterations to run
-	 * </li>
-	 * <li>
-	 * validate Turn XML validation on (<code>true</code>) or off (
-	 * <code>false</code>). If validate is not specified, validation will be
-	 * off.
-	 * </li>
-	 * </ul>
-	 *
-	 *
-	 * @param args DOCUMENT ME!
-	 */
-	public static void main(String[] args) {
-		// Number of Threads
-		int    numThreads = 1;
-		String threadsStr = System.getProperty("threads");
-
-		if (threadsStr != null) {
-			numThreads = Integer.parseInt(threadsStr);
-		}
-
-		// Run test suite in multiple threads?
-		if (numThreads > 1) {
-			// Spawn each thread passing in the Test Suite
-			for (int i = 0; i < numThreads; i++) {
-				TestThread thread =
-					new TestThread(
-								   "EPPSyncExtTst Thread " + i,
-								   EPPSyncExtTst.suite());
-				thread.start();
-			}
-		}
-		else { // Single threaded mode.
-			junit.textui.TestRunner.run(EPPSyncExtTst.suite());
-		}
-	}
-
-	// End EPPSyncExtTst.main(String [])
-
-	/**
-	 * Sets the number of iterations to run per test.
-	 *
-	 * @param aNumIterations number of iterations to run per test
-	 */
-	public static void setNumIterations(long aNumIterations) {
-		numIterations = aNumIterations;
-	}
-
-	// End EPPSyncExtTst.setNumIterations(long)
+  // End EPPSyncExtTst.setNumIterations(long)
 
 }
